"use strict";
exports.__esModule = true;
exports.pieceHistogram = exports.getInitialFromPreset = void 0;
var Color_1 = require("./Color");
var EMPTY = " *  *  *  *  *  *  *  *  * ";
var BOARD3_9 = [
    "-FU-FU-FU-FU-FU-FU-FU-FU-FU",
    EMPTY,
    EMPTY,
    EMPTY,
    "+FU+FU+FU+FU+FU+FU+FU+FU+FU",
    " * +KA *  *  *  *  * +HI * ",
    "+KY+KE+GI+KI+OU+KI+GI+KE+KY",
];
var BOARD2_9 = [EMPTY].concat(BOARD3_9);
/**
 * 既定の初期局面
 */
var presetDefinitions = {
    HIRATE: {
        board: ["-KY-KE-GI-KI-OU-KI-GI-KE-KY", " * -HI *  *  *  *  * -KA * "].concat(BOARD3_9),
        turn: Color_1["default"].Black
    },
    KY: {
        board: ["-KY-KE-GI-KI-OU-KI-GI-KE * ", " * -HI *  *  *  *  * -KA * "].concat(BOARD3_9),
        turn: Color_1["default"].White
    },
    KY_R: {
        board: [" * -KE-GI-KI-OU-KI-GI-KE-KY", " * -HI *  *  *  *  * -KA * "].concat(BOARD3_9),
        turn: Color_1["default"].White
    },
    KA: {
        board: ["-KY-KE-GI-KI-OU-KI-GI-KE-KY", " * -HI *  *  *  *  *  *  * "].concat(BOARD3_9),
        turn: Color_1["default"].White
    },
    HI: {
        board: ["-KY-KE-GI-KI-OU-KI-GI-KE-KY", " *  *  *  *  *  *  * -KA * "].concat(BOARD3_9),
        turn: Color_1["default"].White
    },
    HIKY: {
        board: ["-KY-KE-GI-KI-OU-KI-GI-KE * ", " *  *  *  *  *  *  * -KA * "].concat(BOARD3_9),
        turn: Color_1["default"].White
    },
    "2": {
        board: ["-KY-KE-GI-KI-OU-KI-GI-KE-KY"].concat(BOARD2_9),
        turn: Color_1["default"].White
    },
    "3": {
        board: ["-KY-KE-GI-KI-OU-KI-GI-KE * "].concat(BOARD2_9),
        turn: Color_1["default"].White
    },
    "4": {
        board: [" * -KE-GI-KI-OU-KI-GI-KE * "].concat(BOARD2_9),
        turn: Color_1["default"].White
    },
    "5": {
        board: [" *  * -GI-KI-OU-KI-GI-KE * "].concat(BOARD2_9),
        turn: Color_1["default"].White
    },
    "5_L": {
        board: [" * -KE-GI-KI-OU-KI-GI *  * "].concat(BOARD2_9),
        turn: Color_1["default"].White
    },
    "6": {
        board: [" *  * -GI-KI-OU-KI-GI *  * "].concat(BOARD2_9),
        turn: Color_1["default"].White
    },
    "7_R": {
        board: [" *  *  * -KI-OU-KI-GI *  * "].concat(BOARD2_9),
        turn: Color_1["default"].White
    },
    "7_L": {
        board: [" *  * -GI-KI-OU-KI *  *  * "].concat(BOARD2_9),
        turn: Color_1["default"].White
    },
    "8": {
        board: [" *  *  * -KI-OU-KI *  *  * "].concat(BOARD2_9),
        turn: Color_1["default"].White
    },
    "10": {
        board: [" *  *  *  * -OU *  *  *  * "].concat(BOARD2_9),
        turn: Color_1["default"].White
    }
};
var getInitialFromPreset = function (preset) {
    var definition = presetDefinitions[preset];
    if (!definition) {
        throw new Error("Unknown preset: ".concat(preset));
    }
    return definition;
};
exports.getInitialFromPreset = getInitialFromPreset;
var presets = Object.keys(presetDefinitions);
exports["default"] = presets;
exports.pieceHistogram = {
    FU: 18,
    KY: 4,
    KE: 4,
    GI: 4,
    KI: 4,
    KA: 2,
    HI: 2,
    OU: 2
};
